package gift

import (
	"context"
	"git.noahlan.cn/northlan/ntools-go/kafka"
	"github.com/Shopify/sarama"
	"github.com/zeromicro/go-zero/core/logx"
	"google.golang.org/protobuf/proto"
	"live-service/app/gift/rpc/internal/server"
	"live-service/app/gift/rpc/internal/svc"
	"live-service/app/gift/rpc/pb"
	pbMq "live-service/app/pb/mq"
	kfk "live-service/common/kafka"
	"sync"
)

type msgHandlerFunc func(data []byte, msgKey string)

type MsgToDBHandler struct {
	context context.Context
	ctx     *svc.ServiceContext
	svr     *server.GiftServer

	msgHandle map[string]msgHandlerFunc

	ConsumerGroup *kafka.ConsumerGroup

	mutex sync.Mutex
	logx.Logger
}

func (h *MsgToDBHandler) Init(context context.Context, ctx *svc.ServiceContext, svr *server.GiftServer) {
	h.context = context
	h.ctx = ctx
	h.svr = svr
	h.Logger = logx.WithContext(h.context)

	cfg := ctx.Config.Gift.Kafka
	h.msgHandle = make(map[string]msgHandlerFunc)
	h.msgHandle["gift"] = h.handleGift

	var err error
	h.ConsumerGroup, err = kafka.NewConsumerGroup(&kafka.ConsumerGroupConfig{
		KafkaVersion:   sarama.V3_1_0_0,
		OffsetsInitial: sarama.OffsetNewest,
		IsReturnErr:    false,
		UnMarshaler:    kfk.ProtobufMarshaler,
	}, cfg.Addr, []string{cfg.Topic}, cfg.ConsumerGroupId)

	if err != nil {
		h.Logger.Error(err)
	}
}

func (h *MsgToDBHandler) handleGift(data []byte, msgKey string) {
	// msg proto
	var msgFromMq pbMq.MqGift
	if err := proto.Unmarshal(data, &msgFromMq); err != nil {
		h.Logger.Error("unmarshal msg err", err)
		return
	}
	h.mutex.Lock()
	defer h.mutex.Unlock()
	if _, err := h.svr.CollectGift(context.Background(), &pb.CollectGift{
		Platform:  msgFromMq.Platform,
		GiftId:    msgFromMq.GiftId,
		GiftName:  msgFromMq.GiftName,
		TotalCoin: msgFromMq.TotalCoin,
	}); err != nil {
		h.Logger.Error("收集礼物错误 ", err)
		return
	}
}

func (MsgToDBHandler) Setup(_ sarama.ConsumerGroupSession) error   { return nil }
func (MsgToDBHandler) Cleanup(_ sarama.ConsumerGroupSession) error { return nil }
func (h *MsgToDBHandler) ConsumeClaim(sess sarama.ConsumerGroupSession, claim sarama.ConsumerGroupClaim) error {
	for msg := range claim.Messages() {
		if hFunc, ok := h.msgHandle[msg.Topic]; ok {
			hFunc(msg.Value, string(msg.Key))
		}
		sess.MarkMessage(msg, "")
	}
	return nil
}
