package platform_user

import (
	"encoding/json"
	"fmt"
	"github.com/pkg/errors"
	"io"
	"net/http"
	"strconv"
)

func RetrieveBilibili(pUid string) (*PlatformUser, error) {
	httpResponse, err := http.Get(fmt.Sprintf("https://api.bilibili.com/x/space/acc/info?mid=%s", pUid))
	if err != nil {
		return nil, errors.Wrap(err, "网络错误")
	}
	all, err := io.ReadAll(httpResponse.Body)
	if err != nil {
		return nil, errors.Wrap(err, "读取接口数据错误 IO/Error")
	}
	var resp struct {
		Code    int64                  `json:"code"`
		Message string                 `json:"message"`
		Ttl     int64                  `json:"ttl"` // 未知意义
		Data    map[string]interface{} `json:"data,omitempty"`
	}
	err = json.Unmarshal(all, &resp)
	if err != nil {
		return nil, errors.Wrap(err, "读取接口数据错误 Unmarshal/Error")
	}
	if resp.Code == 0 && resp.Data != nil {
		// 成功
		data, err := json.Marshal(resp.Data)
		if err != nil {
			return nil, errors.Wrap(err, "读取接口数据错误 Marshal/Data/Error")
		}
		return &PlatformUser{
			PUid:    strconv.FormatInt(int64(resp.Data["mid"].(float64)), 10),
			PName:   resp.Data["name"].(string),
			PAvatar: resp.Data["face"].(string),
			PInfo:   string(data),
		}, nil
	} else {
		return nil, errors.New(resp.Message)
	}
}
